import React, { useState, useRef, useContext, useEffect, useMemo } from 'react'
import styles from './index.less'
import { Switch, Input, Table, Form, Popconfirm, Popover } from 'antd'
import Drag from './../../../../components/Drag'
import DragTable from '../../../../components/DragTable'
import { CheckOutlined, DeleteOutlined, MenuOutlined } from '@ant-design/icons'

const colors = [
  // '#ffccc7', '#ffe7ba', '#fffb8f', '#d9f7be', '#b5f5ec',
  // '#bae7ff', '#d6e4ff', '#efdbff', '#ffd6e7', '#e8e8e8',
  // '#ff4d4f', '#ffa940', '#fbce00', '#73d13d', '#36cfc9',
  // '#40a9ff', '#597ef7', '#9254de', '#f759ab', '#8c8c8c',
  'rgb(255, 77, 79)',
  'rgb(255, 169, 64)',
  'rgb(251, 206, 0)',
  'rgba(115, 209, 61)',
  'rgba(54, 207, 201)',
  'rgba(64, 169, 255)',
  'rgba(89, 126, 247)',
  'rgba(146, 84, 222)',
  'rgba(247, 89, 171)',
  'rgba(140, 140, 140)',
  // 'rgba(255, 204, 199)',
  // 'rgba(255, 231, 186)',
  // 'rgba(255, 251, 143)',
  // 'rgba(217, 247, 190)',
  // 'rgba(181, 245, 236)',
  // 'rgba(186, 231, 255)',
  // 'rgba(214, 228, 255)',
  // 'rgba(239, 219, 255)',
  // 'rgba(255, 214, 231)',
  // 'rgba(232, 232, 232)',
]

const SimpleList = (props) => {

  const { value, onChange, addons } = props
  const { color } = addons.formData
  const [visible, setVisible] = useState(false)
  const [text, setText] = useState('')
  const [loading, setLoading] = useState(true)

  useEffect(() => {
    setTimeout(() => {
      setLoading(false)
    }, 0)
  }, [])

  const onPressEnter = (i) => {
    let length = [...value].length
    let array = [...value]
    array.splice(i + 1, 0, { key: `${length + 1}`, index: length + 1, color: colors[length % 10], value: '' })
    onChange(array)
  }

  const inputChange = (item, i) => {
    let array = []
    value.forEach((v, index) => {
      if (index === i) {
        v.value = item
      }
      array.push({ ...v })
    })
    onChange(array)
  }

  const confirm = (index) => {
    let array = []
    value.forEach((v, i) => {
      if (i !== index) {
        array.push({ ...v })
      }
    })
    onChange(array)
  }

  const colorClick = (item, i) => {
    let array = []
    value.forEach((v, index) => {
      if (index === i) {
        v.color = item
      }
      array.push({ ...v })
    })
    onChange(array)
  }

  const rest = (index) => {
    let array = []
    value.forEach((v, i) => {
      if (index === i) {
        v.color = colors[index % 10]
      }
      array.push({ ...v })
    })
    onChange(array)
  }

  const columns = useMemo(() => {
    let columns = [
      {
        title: 'value',
        dataIndex: 'value',
        render: (r, _, i) => {
          return (
            <Input
              onPressEnter={() => onPressEnter(i)}
              onChange={(e) => inputChange(e.target.value, i)}
              value={r}
            />
          )
        }
      },
      {
        title: 'color',
        dataIndex: 'color',
        width: 30,
        render: (r, _, index) => {
          const content = (
            <div>
              <div className={styles.colorTop}>
                <div className={styles.topLeft}>请选择颜色</div>
                <div className={styles.topRight} onClick={() => rest(index)}>重置</div>
              </div>
              <div className={styles.colorBox}>
                {
                  colors.map((v, i) => {
                    return (
                      <div className={styles.colors} style={{ background: v }} onClick={() => colorClick(v, index)}>
                        <CheckOutlined style={{ fontSize: '11px', marginLeft: '5px', display: r === v ? 'inline-block' : 'none' }} />
                      </div>
                    )
                  })
                }
              </div>
            </div>
          )
          return (
            <Popover
              content={content}
              trigger='click'
            >
              <div className={styles.colors} style={{ background: r || '#f2f4f5' }}></div>
            </Popover>
          )
        }
      },
      {
        width: 30,
        render: (r, _, i) => {
          return (
            <Popconfirm
              title='确定删除?'
              onConfirm={() => confirm(i)}
              onCancel={() => { }}
            >
              <DeleteOutlined style={{ color: 'rgb(153, 153, 153)' }} />
            </Popconfirm>
          )
        },
      },
      {
        title: 'Sort',
        dataIndex: 'sort',
        width: 30,
        className: 'drag-visible',
        render: () => <MenuOutlined style={{ cursor: 'grab', color: '#999', }} />,
      },
    ]
    if (!color) {
      return columns.filter(v => v.dataIndex !== 'color')
    }
    return columns
  }, [value, color])

  const switchChange = (checked) => {
    addons.setValue('color', checked)
    if (checked) {
      if (Array.isArray(value)) {
        let array = []
        value.forEach((v, i) => {
          array.push({ ...v, color: colors[i % 10] })
        })
        onChange(array)
      }
    }
  }

  const add = () => {
    let length = [...value].length
    let array = [...value]
    array.push({ key: `${length + 1}`, index: length + 1, color: colors[length % 10], value: '' })
    onChange(array)
  }

  const edit = () => {
    setText(value.map(v => v.value).join('\n'))
    setVisible(true)
  }

  const onOk = () => {
    let array = text.split('\n').map((v, i) => { return { key: `${i}`, index: i, value: v, color: colors[i % 10] } })
    onChange(array)
    setVisible(false)
  }

  const dragCallBack = (array) => {
    if (array) {
      onChange(array)
    }
  }

  return (
    <div className={styles.simpleList}>
      <div className={styles.title}>
        <div style={{ fontSize: '14px' }}>选项</div>
        <div style={{ fontSize: '12px' }}>
          <span style={{ paddingRight: '5px' }}>彩色</span>
          <Switch size='small' checked={color} onChange={switchChange} />
        </div>
      </div>
      <div className={styles.box}>
        {
          loading ? null :
            <DragTable
              dataSource={Array.isArray(value) ? value.map((v, i) => { return { key: `${i}`, index: i, ...v } }) : []}
              showHeader={false}
              rowKey='key'
              ItemTypes='stadingOrder'
              color={color}
              columns={columns}
              pagination={false}
              dragCallBack={dragCallBack}
            />
        }
      </div>
      <div className={styles.footer}>
        <span onClick={add}>添加选项</span>
        <span></span>
        <span onClick={edit}>批量编辑</span>
      </div>
      <Drag
        title='批量编辑'
        onOk={onOk}
        onCancel={() => setVisible(false)}
        visible={visible}
      >
        <Input.TextArea
          rows={5}
          value={text}
          onChange={(e) => setText(e.target.value)}
        />
      </Drag>
    </div>
  )
}

export default SimpleList